import type { CreateTrack } from '../models/CreateTrack';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { ResponseTrack } from '../models/ResponseTrack';
import type { UpdateTrack } from '../models/UpdateTrack';
export declare class TrackService {
    /**
     * Get all
     * Lists all tracks.
     * @returns ResponseTrack
     * @throws ApiError
     */
    static trackControllerGetAll(): Promise<Array<ResponseTrack>>;
    /**
     * Post
     * Create a new track. <br> Please remember that the track's distance must be greater than 0.
     * @param requestBody CreateTrack
     * @returns ResponseTrack
     * @throws ApiError
     */
    static trackControllerPost(requestBody?: CreateTrack): Promise<ResponseTrack>;
    /**
     * Get one
     * Lists all information about the track whose id got provided.
     * @param id
     * @returns ResponseTrack
     * @throws ApiError
     */
    static trackControllerGetOne(id: number): Promise<ResponseTrack>;
    /**
     * Put
     * Update the track whose id you provided. <br> Please remember that ids can't be changed.
     * @param id
     * @param requestBody UpdateTrack
     * @returns ResponseTrack
     * @throws ApiError
     */
    static trackControllerPut(id: number, requestBody?: UpdateTrack): Promise<ResponseTrack>;
    /**
     * Remove
     * Delete the track whose id you provided. <br> If no track with this id exists it will just return 204(no content).
     * @param id
     * @param force
     * @returns ResponseTrack
     * @returns ResponseEmpty
     * @throws ApiError
     */
    static trackControllerRemove(id: number, force?: boolean): Promise<ResponseTrack | ResponseEmpty>;
}
